==> usernotification-8.x-1.1.tar.gz: usernotification/src/Plugin/Action/SendUserNotification.php <==
<?php

namespace Drupal\send_user_notification\Plugin\Action;

use Drupal\Core\Action\ActionBase;
use Drupal\Core\Session\AccountInterface;

/**
 * Sends a Mail to a user.
 *
 * @Action(
 *   id = "send_user_notification_action",
 *   label = @Translation("Send User Notification Message"),
 *   type = "user"
 * )
 */
class SendUserNotification extends ActionBase {

  /**
   * {@inheritdoc}
   */
  public function execute($account = NULL) {
    // Skip blocking user if they are already blocked.
    global $base_url;

    if ($account !== FALSE) {

      $to = $account->getEmail();
      $site_config = \Drupal::config('system.site');
      $site_mail = $site_config->get('mail');
      $site_name = $site_config->get('name');
      $langcode = \Drupal::languageManager()->getCurrentLanguage()->getId();

      $params = [
        'headers' => [
          'Content-Type' => 'text/html; charset=UTF-8;',
          'Content-Transfer-Encoding' => '8Bit',
          'MIME-Version' => '1.0',
          'reply-to' => $site_mail,
        ],
        'from' => $site_mail,
        'account' => $account,
      ];

      $mailManager = \Drupal::service('plugin.manager.mail');
      $module = 'send_user_notification';
      $key = 'user_notification_email';
      $send = TRUE;
      $result = $mailManager->mail($module, $key, $to, $langcode, $params, NULL, $send);
    }
    else {
      drupal_set_message(t('There is some problem in sending the user notification for @user_name. Contact to support!', ['@user_name' => $account->getUsername()]), 'error');
    }

  }

  /**
   * {@inheritdoc}
   */
  public function access($object, AccountInterface $account = NULL, $return_as_object = FALSE) {
    /** @var \Drupal\user\UserInterface $object */
    $access = $object->status->access('edit', $account, TRUE)
      ->andIf($object->access('update', $account, TRUE));

    return $return_as_object ? $access : $access->isAllowed();
  }

}

==> usernotification-8.x-1.4.tar.gz: usernotification/src/Plugin/Action/SendUserNotification.php <==
<?php

namespace Drupal\send_user_notification\Plugin\Action;

use Drupal\Core\Action\ActionBase;
use Drupal\Core\Session\AccountInterface;

/**
 * Sends a Mail to a user.
 *
 * @Action(
 *   id = "send_user_notification_action",
 *   label = @Translation("Send User Notification Message"),
 *   type = "user"
 * )
 */
class SendUserNotification extends ActionBase {

  /**
   * {@inheritdoc}
   */
  public function execute($account = NULL) {
    // Skip blocking user if they are already blocked.
    global $base_url;

    if ($account !== FALSE) {

      $to = $account->getEmail();
      $site_config = \Drupal::config('system.site');
      $site_mail = $site_config->get('mail');
      $site_name = $site_config->get('name');
      $langcode = \Drupal::languageManager()->getCurrentLanguage()->getId();

      $params = [
        'headers' => [
          'Content-Type' => 'text/html; charset=UTF-8;',
          'Content-Transfer-Encoding' => '8Bit',
          'MIME-Version' => '1.0',
          'reply-to' => $site_mail,
        ],
        'from' => $site_mail,
        'account' => $account,
      ];

      $mailManager = \Drupal::service('plugin.manager.mail');
      $module = 'send_user_notification';
      $key = 'user_notification_email';
      $send = TRUE;
      $result = $mailManager->mail($module, $key, $to, $langcode, $params, NULL, $send);
    }
    else {
      \Drupal::messenger()->addMessage(t('There is some problem in sending the user notification for @user_name. Contact to support!', ['@user_name' => $account->getUsername()]), 'error');
    }

  }

  /**
   * {@inheritdoc}
   */
  public function access($object, AccountInterface $account = NULL, $return_as_object = FALSE) {
    /** @var \Drupal\user\UserInterface $object */
    $access = $object->status->access('edit', $account, TRUE)
      ->andIf($object->access('update', $account, TRUE));

    return $return_as_object ? $access : $access->isAllowed();
  }

}
